==> xlniux-client-1.0.4-20141021.084728-3-sources.jar: com/xunlei/niux/client/bonus/BonusClient.java <==
package com.xunlei.niux.client.bonus;

import com.xunlei.niux.client.util.HttpClientUtil;
import com.xunlei.niux.client.util.JsonUtil;
import com.xunlei.niux.client.util.RBundleUtil;
import com.xunlei.niux.client.util.SignUtil;
import com.xunlei.niux.common.exception.NiuRuntimeException;
import com.xunlei.niux.dto.*;

import java.util.HashMap;
import java.util.Map;

public class BonusClient {
	private static String bizNo=RBundleUtil.getString("bonus", "bonusbizno");
	private static String bizPwd=RBundleUtil.getString("bonus", "bonusbizpwd");
	private static String bonusUrl= RBundleUtil.getString("bonus", "bonusurl");;
	public static String consume(String userId,String userName,int transNum,String transNo,String balanceDate,String actNo,String gameId){
		Map<String, String> param = new HashMap<String, String>();
		param.put("userId", userId);
		param.put("userName", userName);
		param.put("transNum", transNum+"");
		param.put("transNo", transNo);
		param.put("bizNo", bizNo);
		param.put("balanceDate",balanceDate);
		param.put("actNo",actNo==null?"":actNo);
		param.put("gameId",gameId==null?"":gameId);
		String sign = SignUtil.sign(param, bizPwd);
		String str=SignUtil.getSignatureContent(param);
		str=str+"&sign="+sign;
		String resp= HttpClientUtil.get(bonusUrl + "/consume.do?" + str);
		if(resp.contains("\"code\":\"00\"")){
			return "00";
		}
		if(resp.contains("\"code\":\"1001\"")){
			//重复处理
			return "00";
		}
		if(resp.contains("\"code\":\"1020\"")){
			return "1020";
		}
		if(resp.contains("\"code\":\"1021\"")){
			return "1021";
		}
		if(resp.contains("\"code\":\"1022\"")){
			return "1022";
		}
		throw new RuntimeException(resp);
	}
	public static void recharge(String userId,String userName,int transNum,String transNo,String balanceDate,String actNo){
		Map<String, String> param = new HashMap<String, String>();
		param.put("userId", userId);
		param.put("userName", userName);
		param.put("transNum", transNum+"");
		param.put("transNo", transNo);
		param.put("bizNo", bizNo);
		param.put("balanceDate",balanceDate);
		param.put("actNo", actNo==null?"":actNo);
		String sign = SignUtil.sign(param, bizPwd);
		String str=SignUtil.getSignatureContent(param);
		str=str+"&sign="+sign;
		String resp=HttpClientUtil.get(bonusUrl+"/recharge.do?"+str);
		if(resp.contains("\"code\":\"00\"")){
			return;
		}
		if(resp.contains("\"code\":\"1001\"")){
			//重复处理
			return;
		}
		throw new RuntimeException(resp);
	}
	public static void recharge(String userId,String userName,int transNum,String transNo,String balanceDate,String p_bizNo,String p_bizPwd,String remark){
		Map<String, String> param = new HashMap<String, String>();
		param.put("userId", userId);
		param.put("userName", userName);
		param.put("transNum", transNum+"");
		param.put("transNo", transNo);
		param.put("bizNo", p_bizNo);
		param.put("balanceDate",balanceDate);
		String sign = SignUtil.sign(param, p_bizPwd);
		String str=SignUtil.getSignatureContent(param);
		str=str+"&sign="+sign+"&remark="+remark;
		String resp=HttpClientUtil.get(bonusUrl+"/recharge.do?"+str);
		if(resp.contains("\"code\":\"00\"")){
			return;
		}
		if(resp.contains("\"code\":\"1001\"")){
			//重复处理
			return;
		}
		throw new RuntimeException(resp);
	}
	public static void returnconsume(String userId,int transNum,String transNo,String balanceDate,String actNo,String gameId){
		Map<String, String> param = new HashMap<String, String>();
		param.put("userId", userId);
		param.put("transNum", transNum+"");
		param.put("transNo", transNo);
		param.put("bizNo", bizNo);
		param.put("balanceDate",balanceDate);
		param.put("actNo",actNo==null?"":actNo);
		param.put("gameId",gameId==null?"":gameId);
		String sign = SignUtil.sign(param, bizPwd);
		String str=SignUtil.getSignatureContent(param);
		str=str+"&sign="+sign;
		String resp=HttpClientUtil.get(bonusUrl+"/returnconsume.do?"+str);
		if(resp.contains("\"code\":\"00\"")){
			return;
		}
		if(resp.contains("\"code\":\"1001\"")){
			//重复处理
			return;
		}
		throw new RuntimeException(resp);
	}
	@SuppressWarnings("unchecked")
	public static UserBonus queryBonus(String userId){
		String resp=HttpClientUtil.get(bonusUrl+"/querybonus.do?userId="+userId);
		if(!resp.contains("\"code\":\"00\"")){
			throw new RuntimeException("出现异常");
		}
		if(resp.contains("\"userBonus\":null")){
			return null;
		}
		try {
			Map<String,Object> respMap=(Map<String, Object>) JsonUtil.jsonToObject(resp.substring(9, resp.length() - 1));
			respMap=(Map<String, Object>) respMap.get("data");
			respMap=(Map<String, Object>) respMap.get("userBonus");
			UserBonus userBonus=new UserBonus();
			userBonus.setBonusLevel(Integer.valueOf((String)respMap.get("bonusLevel")));
			userBonus.setConsumeSum(Integer.valueOf((String)respMap.get("consumeSum")));
			userBonus.setBonusStatus((String)respMap.get("bonusStatus"));
			userBonus.setRechargeSum(Integer.valueOf((String)respMap.get("rechargeSum")));
			userBonus.setBonusNum(Integer.valueOf((String)respMap.get("bonusNum")));
			userBonus.setUserName((String)respMap.get("userName"));
			userBonus.setUserId((String)respMap.get("userId"));
			userBonus.setNextLevelNeedNum(Integer.valueOf((String)respMap.get("nextLevelNeedNum")));
			userBonus.setLevelName((String)respMap.get("levelName"));
			userBonus.setLevelUrl((String)respMap.get("levelUrl"));
			userBonus.setBonusRanking(Long.valueOf(((String)respMap.get("bonusRanking"))));
			return userBonus;
		} catch (Exception e) {
			throw new RuntimeException("出现异常");
		}
	}
	@SuppressWarnings("unchecked")
	public static Map<String,Object> getBonusSort(String userId)throws Exception{
		String resp=HttpClientUtil.get(bonusUrl+"/querybonussort.do?userId="+userId);
		Map<String,Object> respMap=(Map<String, Object>) JsonUtil.jsonToObject(resp.substring(9, resp.length()-1));
		return (Map<String, Object>) respMap.get("data");
	}
	public static void checkBonusEnough(String userId,int bonusNum){
		String resp=HttpClientUtil.get(bonusUrl+"/checkenoughconsume.do?userId="+userId+"&bonusNum="+bonusNum);
		if(resp.contains("\"code\":\"00\"")){
			return;
		}
		if(resp.contains("\"code\":\"1020\"")){
			throw new NiuRuntimeException("1020", "积分不存在");
		}
		if(resp.contains("\"code\":\"1021\"")){
			throw new NiuRuntimeException("1021", "积分不够");
		}
		if(resp.contains("\"code\":\"1022\"")){
			throw new NiuRuntimeException("1022", "积分不够");
		}
		throw new RuntimeException(resp);
	}

}

==> xlniux-client-1.0.7-20150331.084510-5-sources.jar: com/xunlei/niux/client/bonus/BonusClient.java <==
package com.xunlei.niux.client.bonus;

import com.xunlei.niux.client.util.HttpClientUtil;
import com.xunlei.niux.client.util.JsonUtil;
import com.xunlei.niux.client.util.SignUtil;
import com.xunlei.niux.common.exception.NiuRuntimeException;
import com.xunlei.niux.dto.*;
import com.xunlei.niux.easyutils.propertyutils.EnvPropertyUtil;

import java.util.HashMap;
import java.util.Map;

public class BonusClient {
	private static String bizNo= EnvPropertyUtil.loadProperty("bonus", "bonusbizno");
	private static String bizPwd=EnvPropertyUtil.loadProperty("bonus", "bonusbizpwd");
	private static String bonusUrl= EnvPropertyUtil.loadProperty("bonus", "bonusurl");
	public static String consume(String userId,String userName,int transNum,String transNo,String balanceDate,String actNo,String gameId){
		Map<String, String> param = new HashMap<String, String>();
		param.put("userId", userId);
		param.put("userName", userName);
		param.put("transNum", transNum+"");
		param.put("transNo", transNo);
		param.put("bizNo", bizNo);
		param.put("balanceDate",balanceDate);
		param.put("actNo",actNo==null?"":actNo);
		param.put("gameId",gameId==null?"":gameId);
		String sign = SignUtil.sign(param, bizPwd);
		String str=SignUtil.getSignatureContent(param);
		str=str+"&sign="+sign;
		String resp= HttpClientUtil.get(bonusUrl + "/consume.do?" + str);
		if(resp.contains("\"code\":\"00\"")){
			return "00";
		}
		if(resp.contains("\"code\":\"1001\"")){
			//重复处理
			return "00";
		}
		if(resp.contains("\"code\":\"1020\"")){
			return "1020";
		}
		if(resp.contains("\"code\":\"1021\"")){
			return "1021";
		}
		if(resp.contains("\"code\":\"1022\"")){
			return "1022";
		}
		throw new RuntimeException(resp);
	}
	public static void recharge(String userId,String userName,int transNum,String transNo,String balanceDate,String actNo){
		Map<String, String> param = new HashMap<String, String>();
		param.put("userId", userId);
		param.put("userName", userName);
		param.put("transNum", transNum+"");
		param.put("transNo", transNo);
		param.put("bizNo", bizNo);
		param.put("balanceDate",balanceDate);
		param.put("actNo", actNo==null?"":actNo);
		String sign = SignUtil.sign(param, bizPwd);
		String str=SignUtil.getSignatureContent(param);
		str=str+"&sign="+sign;
		String resp=HttpClientUtil.get(bonusUrl+"/recharge.do?"+str);
		if(resp.contains("\"code\":\"00\"")){
			return;
		}
		if(resp.contains("\"code\":\"1001\"")){
			//重复处理
			return;
		}
		throw new RuntimeException(resp);
	}
	public static void recharge(String userId,String userName,int transNum,String transNo,String balanceDate,String p_bizNo,String p_bizPwd,String remark){
		Map<String, String> param = new HashMap<String, String>();
		param.put("userId", userId);
		param.put("userName", userName);
		param.put("transNum", transNum+"");
		param.put("transNo", transNo);
		param.put("bizNo", p_bizNo);
		param.put("balanceDate",balanceDate);
		String sign = SignUtil.sign(param, p_bizPwd);
		String str=SignUtil.getSignatureContent(param);
		str=str+"&sign="+sign+"&remark="+remark;
		String resp=HttpClientUtil.get(bonusUrl+"/recharge.do?"+str);
		if(resp.contains("\"code\":\"00\"")){
			return;
		}
		if(resp.contains("\"code\":\"1001\"")){
			//重复处理
			return;
		}
		throw new RuntimeException(resp);
	}
	public static void returnconsume(String userId,int transNum,String transNo,String balanceDate,String actNo,String gameId){
		Map<String, String> param = new HashMap<String, String>();
		param.put("userId", userId);
		param.put("transNum", transNum+"");
		param.put("transNo", transNo);
		param.put("bizNo", bizNo);
		param.put("balanceDate",balanceDate);
		param.put("actNo",actNo==null?"":actNo);
		param.put("gameId",gameId==null?"":gameId);
		String sign = SignUtil.sign(param, bizPwd);
		String str=SignUtil.getSignatureContent(param);
		str=str+"&sign="+sign;
		String resp=HttpClientUtil.get(bonusUrl+"/returnconsume.do?"+str);
		if(resp.contains("\"code\":\"00\"")){
			return;
		}
		if(resp.contains("\"code\":\"1001\"")){
			//重复处理
			return;
		}
		throw new RuntimeException(resp);
	}
	@SuppressWarnings("unchecked")
	public static UserBonus queryBonus(String userId){
		String resp=HttpClientUtil.get(bonusUrl+"/querybonus.do?userId="+userId);
		if(!resp.contains("\"code\":\"00\"")){
			throw new RuntimeException("出现异常");
		}
		if(resp.contains("\"userBonus\":null")){
			return null;
		}
		try {
			Map<String,Object> respMap=(Map<String, Object>) JsonUtil.jsonToObject(resp.substring(9, resp.length() - 1));
			respMap=(Map<String, Object>) respMap.get("data");
			respMap=(Map<String, Object>) respMap.get("userBonus");
			UserBonus userBonus=new UserBonus();
			userBonus.setBonusLevel(Integer.valueOf((String)respMap.get("bonusLevel")));
			userBonus.setConsumeSum(Integer.valueOf((String)respMap.get("consumeSum")));
			userBonus.setBonusStatus((String)respMap.get("bonusStatus"));
			userBonus.setRechargeSum(Integer.valueOf((String)respMap.get("rechargeSum")));
			userBonus.setBonusNum(Integer.valueOf((String)respMap.get("bonusNum")));
			userBonus.setUserName((String)respMap.get("userName"));
			userBonus.setUserId((String)respMap.get("userId"));
			userBonus.setNextLevelNeedNum(Integer.valueOf((String)respMap.get("nextLevelNeedNum")));
			userBonus.setLevelName((String)respMap.get("levelName"));
			userBonus.setLevelUrl((String)respMap.get("levelUrl"));
			userBonus.setBonusRanking(Long.valueOf(((String)respMap.get("bonusRanking"))));
			return userBonus;
		} catch (Exception e) {
			throw new RuntimeException("出现异常");
		}
	}
	@SuppressWarnings("unchecked")
	public static Map<String,Object> getBonusSort(String userId)throws Exception{
		String resp=HttpClientUtil.get(bonusUrl+"/querybonussort.do?userId="+userId);
		Map<String,Object> respMap=(Map<String, Object>) JsonUtil.jsonToObject(resp.substring(9, resp.length()-1));
		return (Map<String, Object>) respMap.get("data");
	}
	public static void checkBonusEnough(String userId,int bonusNum){
		String resp=HttpClientUtil.get(bonusUrl+"/checkenoughconsume.do?userId="+userId+"&bonusNum="+bonusNum);
		if(resp.contains("\"code\":\"00\"")){
			return;
		}
		if(resp.contains("\"code\":\"1020\"")){
			throw new NiuRuntimeException("1020", "积分不存在");
		}
		if(resp.contains("\"code\":\"1021\"")){
			throw new NiuRuntimeException("1021", "积分不够");
		}
		if(resp.contains("\"code\":\"1022\"")){
			throw new NiuRuntimeException("1022", "积分不够");
		}
		throw new RuntimeException(resp);
	}

}
